==> de.duehl.vocabulary.japanese_0.05.00_sources.zip: de.duehl.vocabulary.japanese_0.05.00/de.duehl.vocabulary.japanese/src/de/duehl/vocabulary/japanese/ui/dialog/vocables/detail/related/VerbsAndAdjectivesFinderGui.java <==
package de.duehl.vocabulary.japanese.ui.dialog.vocables.detail.related;

import java.awt.Point;

import javax.swing.JPanel;

import de.duehl.swing.logic.LongTimeProcessInformer;
import de.duehl.vocabulary.japanese.data.FumikoDataStructures;
import de.duehl.vocabulary.japanese.data.Vocable;
import de.duehl.vocabulary.japanese.grammar.AdjectivePositivePresenceFinder;
import de.duehl.vocabulary.japanese.grammar.VerbWoerterbuchformFinder;
import de.duehl.vocabulary.japanese.ui.data.FumikoUiObjects;

/**
 * Diese Klasse stellt Buttons bereit, um zu einer Vokabel zugehörige Verb- und Adjektivformen zu
 * finden, wenn die Vokabel ein Verb bzw. ein Adjektiv ist.
 *
 * @version 1.01     2025-11-26
 * @author Christian Dühl
 */

public class VerbsAndAdjectivesFinderGui {

    /** Die angezeigte Vokabel. */
    private final Vocable vocable;

    /** Die Datenstrukturen des Vokabeltrainers. */
    private final FumikoDataStructures dataStructures;

    /** Findet zur angezeigten Vokabel gehörige Verb- und Adjektivformen. */
    private final VerbsAndAdjectivesFinder verbsAndAdjectivesFinder;

    /** Stellt die Buttons wirklich dar. */
    private final VerbAndAdjectiveButtonsCreator creator;

    /**
     * Konstruktor.
     *
     * @param vocable
     *            Die angezeigte Vokabel.
     * @param dataStructures
     *            Die Datenstrukturen des Vokabeltrainers.
     * @param uiObjects
     *            Die häufig verwendeten Funktionen der grafischen Oberfläche des Vokabeltrainers.
     * @param location
     *            Die Position des Rahmens der Oberfläche, die den Panel anzeigt, welcher diese
     *            Klasse verwendet.
     * @param longTimeProcessInformer
     *            Die Oberfläche, welche diese Klasse aufruft, auf der man eine GlassPane anzeigen
     *            kann.
     */
    public VerbsAndAdjectivesFinderGui(Vocable vocable, FumikoDataStructures dataStructures,
            FumikoUiObjects uiObjects, Point location,
            LongTimeProcessInformer longTimeProcessInformer) {
        this.vocable = vocable;
        this.dataStructures = dataStructures;

        verbsAndAdjectivesFinder = new VerbsAndAdjectivesFinder(dataStructures, uiObjects, location,
                longTimeProcessInformer);
        creator = new VerbAndAdjectiveButtonsCreator(vocable, verbsAndAdjectivesFinder);
    }

    /**
     * Fügt zum übergebenen Panel Buttons zur Anzeige der Verb- bzw. Adjektivformen an, abhängig
     * davon, ob die Vokabel ein Verb bzw. Adjektiv ist.
     *
     * @param panel
     *            Der Panel dem die Buttons hinzugefügt werden sollen. Dieser sollte ein Layout
     *            haben, das das Hinzufügen von Elemente ohne weitere Parameter gestattet, wie z.B.
     *            das VerticalLayout.
     */
    public void appendButtonsToPanel(JPanel panel) {
        if (vocable.isVerbInWoerterbuchform()) {
            panel.add(creator.createFindRelatedVerbsButton());
        }
        else if (vocable.isVerb()) {
            Vocable woerterbuchform = VerbWoerterbuchformFinder.determineWoerterbuchform(vocable,
                    dataStructures.getVocabularies());
            if (!woerterbuchform.equals(VerbWoerterbuchformFinder.NO_WOERTERBUCHFORM_FOUND)) {
                panel.add(
                        creator.createFindRelatedVerbsButtonViaWoerterbuchform(woerterbuchform));
            }
        }
        else if (vocable.isAdjectivInPositivePresence()) {
            panel.add(creator.createFindRelatedAdjectiveButton());
        }
        else if (vocable.isAdjective()) {
            Vocable positivePresence = AdjectivePositivePresenceFinder.determinePositivePresence(
                    vocable, dataStructures.getVocabularies());
            if (!positivePresence.equals(
                    AdjectivePositivePresenceFinder.NO_POSITIVE_PRESENCE_FOUND)) {
                panel.add(
                        creator.createFindRelatedAdjectiveButtonViaPositivePresence(
                                positivePresence));
            }
        }
    }

}

==> de.duehl.vocabulary.japanese_0.05.41_sources.zip: de.duehl.vocabulary.japanese_0.05.41/de.duehl.vocabulary.japanese/src/de/duehl/vocabulary/japanese/ui/dialog/vocables/detail/related/VerbsAndAdjectivesFinderGui.java <==
package de.duehl.vocabulary.japanese.ui.dialog.vocables.detail.related;

import java.awt.Point;

import javax.swing.JPanel;

import de.duehl.swing.logic.LongTimeProcessInformer;
import de.duehl.vocabulary.japanese.data.FumikoDataStructures;
import de.duehl.vocabulary.japanese.data.Vocable;
import de.duehl.vocabulary.japanese.grammar.AdjectivePositivePresenceFinder;
import de.duehl.vocabulary.japanese.grammar.VerbWoerterbuchformFinder;
import de.duehl.vocabulary.japanese.ui.data.FumikoUiObjects;

/**
 * Diese Klasse stellt Buttons bereit, um zu einer Vokabel zugehörige Verb- und Adjektivformen zu
 * finden, wenn die Vokabel ein Verb bzw. ein Adjektiv ist.
 *
 * @version 1.01     2026-01-05
 * @author Christian Dühl
 */

public class VerbsAndAdjectivesFinderGui {

    /** Die angezeigte Vokabel. */
    private final Vocable vocable;

    /** Die Datenstrukturen des Vokabeltrainers. */
    private final FumikoDataStructures dataStructures;

    /** Findet zur angezeigten Vokabel gehörige Verb- und Adjektivformen. */
    private final VerbsAndAdjectivesFinder verbsAndAdjectivesFinder;

    /** Stellt die Buttons wirklich dar. */
    private final VerbAndAdjectiveButtonsCreator creator;

    /**
     * Konstruktor.
     *
     * @param vocable
     *            Die angezeigte Vokabel.
     * @param dataStructures
     *            Die Datenstrukturen des Vokabeltrainers.
     * @param uiObjects
     *            Die häufig verwendeten Funktionen der grafischen Oberfläche des Vokabeltrainers.
     * @param location
     *            Die Position des Rahmens der Oberfläche, die den Panel anzeigt, welcher diese
     *            Klasse verwendet.
     * @param longTimeProcessInformer
     *            Die Oberfläche, welche diese Klasse aufruft, auf der man eine GlassPane anzeigen
     *            kann.
     */
    public VerbsAndAdjectivesFinderGui(Vocable vocable, FumikoDataStructures dataStructures,
            FumikoUiObjects uiObjects, Point location,
            LongTimeProcessInformer longTimeProcessInformer) {
        this.vocable = vocable;
        this.dataStructures = dataStructures;

        verbsAndAdjectivesFinder = new VerbsAndAdjectivesFinder(dataStructures, uiObjects, location,
                longTimeProcessInformer);
        creator = new VerbAndAdjectiveButtonsCreator(vocable, verbsAndAdjectivesFinder);
    }

    /**
     * Fügt zum übergebenen Panel Buttons zur Anzeige der Verb- bzw. Adjektivformen an, abhängig
     * davon, ob die Vokabel ein Verb bzw. Adjektiv ist.
     *
     * Eine Vokabel kann sogar sowohl Adjektiv als auch Verb sein (z.B. 「暇」 (「ひま」, hima), in
     * diesem Fall ein Suru-Verb und ein Na-Adjektiv), darum wird hier nicht alles mit else
     * versehen.
     *
     * @param panel
     *            Der Panel dem die Buttons hinzugefügt werden sollen. Dieser sollte ein Layout
     *            haben, das das Hinzufügen von Elemente ohne weitere Parameter gestattet, wie z.B.
     *            das VerticalLayout.
     */
    public void appendButtonsToPanel(JPanel panel) {
        if (vocable.isVerbInWoerterbuchform()) {
            panel.add(creator.createFindRelatedVerbsButton());
        }
        else if (vocable.isVerb()) {
            Vocable woerterbuchform = VerbWoerterbuchformFinder.determineWoerterbuchform(vocable,
                    dataStructures.getVocabularies());
            if (!woerterbuchform.equals(VerbWoerterbuchformFinder.NO_WOERTERBUCHFORM_FOUND)) {
                panel.add(
                        creator.createFindRelatedVerbsButtonViaWoerterbuchform(woerterbuchform));
            }
        }

        if (vocable.isAdjectivInPositivePresence()) {
            panel.add(creator.createFindRelatedAdjectiveButton());
        }
        else if (vocable.isAdjective()) {
            Vocable positivePresence = AdjectivePositivePresenceFinder.determinePositivePresence(
                    vocable, dataStructures.getVocabularies());
            if (!positivePresence.equals(
                    AdjectivePositivePresenceFinder.NO_POSITIVE_PRESENCE_FOUND)) {
                panel.add(
                        creator.createFindRelatedAdjectiveButtonViaPositivePresence(
                                positivePresence));
            }
        }
    }

}
